<?php  if ( ! defined('BASEPATH')) exit('No direct script access allowed');

/**
 * ExpressionEngine - by EllisLab
 *
 * @package		ExpressionEngine
 * @author		ExpressionEngine Dev Team
 * @copyright	Copyright (c) 2003 - 2011, EllisLab, Inc.
 * @license		http://expressionengine.com/user_guide/license.html
 * @link		http://expressionengine.com
 * @since		Version 2.0
 * @filesource
 */
 
// ------------------------------------------------------------------------

/**
 * Twitter Recent Tweets Plugin
 *
 * @package		ExpressionEngine
 * @subpackage	Addons
 * @category	Plugin
 * @author		Adpearance
 * @link		http://adpearance.com
 */

$plugin_info = array(
	'pi_name'		=> 'Twitter Recent Tweets',
	'pi_version'	=> '1.0',
	'pi_author'		=> 'Adpearance',
	'pi_author_url'	=> 'http://adpearance.com',
	'pi_description'=> 'Twitter Recent Tweets',
	'pi_usage'		=> Twitter_recent_tweets::usage()
);


class Twitter_recent_tweets {

	public $return_data;
	private $predefined;
    
	/**
	 * Constructor
	 */
	public function __construct()
	{
		$this->EE =& get_instance();
		
		$this->predefined = array(
			'screen_name' => 'adpearance',
			'count' => 5,
			'trim_user' => 1,
			'exclude_replies' => 1,
			'contributor_details' => 0,
			'include_rts' => 0
		);
	}

	
	
	function get_tweets()
	{
		//required params
		$oauth_access_token = $this->EE->TMPL->fetch_param('oauth_access_token');
		$oauth_access_token_secret = $this->EE->TMPL->fetch_param('oauth_access_token_secret');
		$consumer_key = $this->EE->TMPL->fetch_param('consumer_key');
		$consumer_secret = $this->EE->TMPL->fetch_param('consumer_secret');
		
		$screen_name = $this->EE->TMPL->fetch_param('screen_name');
		$count = $this->EE->TMPL->fetch_param('count');
		$trim_user = $this->EE->TMPL->fetch_param('trim_user');
		$exclude_replies = $this->EE->TMPL->fetch_param('exclude_replies');
		$contributor_details = $this->EE->TMPL->fetch_param('contributor_details');
		$include_rts = $this->EE->TMPL->fetch_param('include_rts');
		
		$options = array();

		if ($count !== false) $options['count'] = $count;

		if ($trim_user !== false) $options['trim_user'] = $trim_user;

		if ($exclude_replies !== false) $options['exclude_replies'] = $exclude_replies;

		if ($contributor_details !== false) $options['contributor_details'] = $contributor_details;

		if ($include_rts !== false) $options['include_rts'] = $include_rts;

		if ($screen_name !== false) $options['screen_name'] = $screen_name;

		$options = array_merge($this->predefined, $options);

		$tagdata = $this->EE->TMPL->tagdata;

		require_once('TwitterAPIExchange.php');

		/** Set access tokens here - see: https://dev.twitter.com/apps/ **/
		$settings = array(
			'oauth_access_token' => $oauth_access_token,
			'oauth_access_token_secret' => $oauth_access_token_secret,
			'consumer_key' => $consumer_key,
			'consumer_secret' => $consumer_secret
		);

		/** Perform a GET request and echo the response **/
		$url = 'https://api.twitter.com/1.1/statuses/user_timeline.json';
		
		
		$getfield = '?'.http_build_query($options);


		$requestMethod = 'GET';
		$twitter = new TwitterAPIExchange($settings);
		$response = $twitter->setGetfield($getfield)->buildOauth($url, $requestMethod)->performRequest();

		$twitterTimelineObj = json_decode($response);
		


		if (isset($twitterTimelineObj->errors[0]->code))
		{
			$variables[0]['error'] = 'Error Code: '.$twitterTimelineObj->errors[0]->code;
			return 'Error Code: '.$twitterTimelineObj->errors[0]->code;
		}

		if (count($response) != 0)
		{
			$iterator = 0;
			foreach($twitterTimelineObj as $keyTweet => $tweet){

				$tweet_text = htmlentities($tweet->text, ENT_QUOTES);
				$tweet_text = preg_replace('/http:\/\/([a-z0-9_\.\-\+\&\!\#\~\/\,]+)/i', '<a href="http://$1" target="_blank">http://$1</a>', $tweet_text);
				$tweet_text = preg_replace('/@([a-z0-9_]+)/i', '<a href="http://twitter.com/$1" target="_blank">@$1</a>', $tweet_text);
				$tweet->text = $tweet_text;
				$tweet->time_ago = $twitter->twitter_time($tweet->created_at);
				
				$variables[$iterator] = (array)$tweet;

				if ($options['trim_user'] == 0)
				{
					foreach($variables[$iterator]['user'] as $keyAuthor => $valAuthor)
					{
						$variables[$iterator]['author_'.$keyAuthor] = $valAuthor;
					}
				}
				
				// get ride of extra values
				unset($variables[$iterator]['user']);
				unset($variables[$iterator]['entities']);
				unset($variables[$iterator]['author_entities']);

				$iterator++;
			}
		}
		else{
			return 'No Tweets';
		}

		return $this->EE->TMPL->parse_variables($this->EE->TMPL->advanced_conditionals($tagdata), $variables);
	}
	
	// ----------------------------------------------------------------
	
	/**
	 * Plugin Usage
	 */
	public static function usage()
	{
		ob_start();
?>

Built on the new oauth twitter api v1.1, it pulls the most recent tweats for any given Twitter account.

Example of full code usage: 
{exp:twitter_recent_tweets:get_tweets 
	oauth_access_token="xxxxx" <!--required-->
	oauth_access_token_secret="xxxxx" <!--required-->
	consumer_key="xxxxx" <!--required-->
	consumer_secret="xxxxx" <!--required-->
	screen_name="adpearance" <!--optional-->
	count="3" <!--optional-->
	trim_user="1" <!--optional-->
	exclude_replies="1" <!--optional-->
	contributor_details="0" <!--optional-->
	include_rts="0" <!--optional-->
}

		{text}
		{time_ago}
		{created_at}

{/exp:twitter_recent_tweets:get_tweets}

Note: The count parameter limits the number of tweets returned. The count is generated before the retweets are taken into account and before determining if a tweet status is closed so less tweets might be returned. This is a twitter api limitation.

To find your oauth access and consumer tokens. 
	#1 Login / Register on the  Twitter website
	#2 Go to: https://dev.twitter.com/
	#3 Click "My Applications" on the top right ( Hover over your account.)
	#4 Fill out the information and create your application
	#5 Click Create my access token


At this point you should be ready to roll Copy the code example above, replace the authentication tokens and tailor it at will. 

EE Tags Returned
	{created_at}
	[id}
	{text}
	{source}
	{retweet_count} 
	{favorite_count}
	{favorited}
	{retweeted}
	{possibly_sensitive}
	{lang}
	{time_ago}





<?php
		$buffer = ob_get_contents();
		ob_end_clean();
		return $buffer;
	}
}


/* End of file pi.twitter_recent_tweets.php */
/* Location: /system/expressionengine/third_party/twitter_recent_tweets/pi.twitter_recent_tweets.php */